@@ -56,57 +56,11 @@ mc1 <- function(ac, wr = FALSE) {
   ## Set conc to three significant figures
   dat[ , conc := signif(conc, 3)]
   
-  ## Define replicate id
-  # Order by the following columns
-  setkeyv(dat, c('acid', 'srcf', 'apid', 'coli', 'rowi', 'spid', 'conc')) 
-  # Define rpid column for test compound wells
-  nconc <- dat[wllt == "t" , 
-               list(n = lu(conc)), 
-               by = list(acid, apid, spid)][ , list(nconc = min(n)), by = acid]
-  dat[wllt == "t" & acid %in% nconc[nconc > 1, acid],
-      rpid := paste(acid, spid, wllt, srcf, apid, "rep1", conc, sep = "_")]
-  dat[wllt == "t" & acid %in% nconc[nconc == 1, acid],
-      rpid := paste(acid, spid, wllt, srcf, "rep1", conc, sep = "_")]
-  # Define rpid column for non-test compound wells
-  dat[wllt != "t", 
-      rpid := paste(acid, spid, wllt, srcf, apid, "rep1", conc, sep = "_")] 
-  # Increment rpid 
-  dat_rpid <- dat[ , rpid]
-  j = 2L
-  while (any(duplicated(dat_rpid))) {
-    ind <- duplicated(dat_rpid)
-    dat_rpid[ind] <- sub("_rep[0-9]+", paste0("_rep", j), dat_rpid[ind])
-    j <- j + 1
-  }
-  dat[ , rpid := dat_rpid]
-  rm(dat_rpid)
-  # Remove conc values from rpid
-  dat[ , rpid := sub("_([^_]+)$", "", rpid, useBytes = TRUE)]
+  # set concentration index
+  dat[, cndx := frank(conc, ties.method = "dense"), by = .(acid, spid, wllt, srcf, apid)]
   
-  ## Define concentration index
-  indexfunc <- function(x) as.integer(rank(unique(x))[match(x, unique(x))])
-  dat[ , cndx := indexfunc(conc), by = list(rpid)]
-  
-  ## Define replicate index
-  # Create temporary table containing the unique replicate ids
-
-  trdt <- unique(dat[wllt %in% c("t", "c") , list(acid, spid, wllt, rpid)])
-  trdt_rpid <- trdt[ , rpid]
-  trdt[ , rpid := NULL]
-  trdt[ , repi := 1]
-  # Increment repi
-  while (any(duplicated(trdt))) {
-    trdt[duplicated(trdt), repi := repi + 1]
-  }
-  trdt[ , rpid := trdt_rpid]
-  rm(trdt_rpid)
-  # Map replicate index back to dat
-  setkey(dat, rpid)
-  setkey(trdt, rpid)
-  dat[ , repi := trdt[dat, repi]]
-  
-  ## Remove rpid column
-  dat[, rpid := NULL]
+  # set replicate index
+  dat[, repi:=rowid(conc),by= .(acid, spid, wllt, srcf, apid)]
   
   ttime <- round(difftime(Sys.time(), stime, units = "sec"), 2)
   ttime <- paste(unclass(ttime), units(ttime))
