@@ -106,8 +106,6 @@
 #'   \item{maxmed20pct}{Add a cutoff value of 20 percent of the maximum of all endpoint maximal 
 #'   average response values (max_med).}
 #'   \item{coff_2.32}{Add a cutoff value of 2.32.}
-#'   \item{loec.coff}{Method not yet updated for tcpl implementation. Identify the lowest observed 
-#'   effective concentration (loec) compared to baseline.}
 #'   \item{ow_bidirectional_loss}{Multiply winning model hitcall (hitc) by -1 for models fit in the 
 #'   positive analysis direction. Typically used for endpoints where only negative responses are 
 #'   biologically relevant.}
@@ -115,6 +113,13 @@
 #'   negative analysis direction. Typically used for endpoints where only positive responses are 
 #'   biologically relevant.}
 #'   \item{osd_coff_bmr}{Overwrite the osd value so that bmr equals cutoff.}
+#'   \item{ow_loec.coff}{Identify the lowest observed effective concentration (loec) where the values 
+#'   of all responses are outside the cutoff band (i.e. abs(resp) > cutoff). loec is stored alongside 
+#'   winning model and potency estimates. If loec exists, assume hit call = 1, fitc = 100, 
+#'   model_type = 1, and if not, assume hit call = 0.}
+#'   \item{include_loec.coff}{Identify the lowest observed effective concentration (loec) where the 
+#'   values of all responses are outside the cutoff band (i.e. abs(resp) > cutoff). loec is 
+#'   stored alongside winning model and potency estimates.}
 #'  }
 #' }
 #'
@@ -350,6 +355,27 @@ mc5_mthds <- function(ae) {
       e1 <- bquote(coff <- c(coff, 40))
       list(e1)
 
+    },
+    
+    ow_loec.coff = function() {
+      
+      # get all endpoint sample m4ids where the loec param is not na
+      e1 <- bquote(loec.m4ids <- dat[(hit_param == "loec") & !is.na(hit_val), unique(m4id)])
+      # set hitcall and hitc param to 1 if found in m4id list and 0 if not
+      e2 <- bquote(dat[hit_param == "hitcall", hit_val:=ifelse(m4id %in% loec.m4ids, 1, 0)])
+      e3 <- bquote(dat[, hitc:=ifelse(m4id %in% loec.m4ids, 1, 0)])
+      # update modl to loec, fitc to 100, model_type to 1
+      e4 <- bquote(dat[, c("modl", "fitc", "model_type") := list("loec", 100L, 1)])
+      list(e1, e2, e3, e4)
+      
+    },
+    
+    include_loec.coff = function() {
+      
+      e1 <- bquote(dat <- rbind(dat, mc3, fill = TRUE) |> arrange(m4id))
+      e2 <- bquote(dat <- dat |> group_by(m4id) |> tidyr::fill(modl,hitc,fitc,model_type) |> as.data.table())
+      list(e1, e2)
+      
     }
 
   )
