@@ -10,7 +10,7 @@
   packageStartupMessage("tcpl (v", as.character(utils::packageVersion("tcpl")), 
                         ") loaded with the following settings:\n  ",
                         paste(cs, collapse = "\n  "),
-                        "\nDefault settings stored in TCPL.conf. See ", 
+                        "\nDefault settings stored in tcpl config file. See ", 
                         "?tcplConf for more information.")
   
 }
