@@ -28,6 +28,9 @@ tcplAppend <- function(dat, tbl, db, lvl=NULL) {
   
   db_pars <- NULL
   
+  if (getOption("TCPL_DRVR") == "API") {
+    stop("'API' driver not supported in tcplAppend.")
+  }
   
   if (getOption("TCPL_DRVR") == "MySQL") {
     
@@ -46,6 +49,11 @@ tcplAppend <- function(dat, tbl, db, lvl=NULL) {
     names(additional_pars) <- tolower(gsub("TCPL_","",names(additional_pars)))
     db_pars <- append(db_pars,additional_pars)
     
+    if("RMySQL" %in% loadedNamespaces()){
+      unloadNamespace("RMySQL")
+      warning("'RMySQL' package is not supported with tcpl and has been detached.")
+    }
+    
     dbcon <- do.call(dbConnect, db_pars)
 
     
@@ -61,63 +69,6 @@ tcplAppend <- function(dat, tbl, db, lvl=NULL) {
     
   }
   
-  if (getOption("TCPL_DRVR") == "tcplLite") {
-  # Rather than write to db, write to appropriate csv in db dir  
-    db_pars <- db
-    fpath <- paste(db, tbl, sep='/') # Stitch together the dir path and the level table we're working on
-    fpath <- paste(fpath, 'csv', sep='.')
-    
-    tbl_cols <- colnames(read.table(fpath, header=T, sep=',', fill=T))
-    if (length(setdiff(tbl_cols,names(dat)))>0){
-      setDT(dat)[, setdiff(tbl_cols, names(dat)) := NA]
-    }else{
-      setDT(dat)
-    }
-    
-    setcolorder(dat, tbl_cols)
-
-    
-    # Need to set the "<type><lvl>id" column. Don't have the luxury of the sql auto increment schema
-    autoFlag <- T
-    if (!is.null(lvl)) {
-      if (lvl %in% 0L:6L) {
-        if (startsWith(tbl, "mc")) {
-          autoIncr <- paste0("m",lvl,"id")
-        } else if (startsWith(tbl, "sc")) {
-          autoIncr <- paste0("s", lvl, "id")
-        } 
-      } else if (lvl == "acid") {
-        autoIncr <- "acid"
-      } else if (lvl == "aeid") {
-          autoIncr <- "aeid"
-      } else if (lvl == "aid") {
-        autoIncr <- "aid"
-      } else if (lvl == "asid") {
-        autoIncr <- "asid"
-      } else {
-        autoFlag <- F
-      }
-      
-      if (autoFlag == T){
-        temp_dt <- read.csv(fpath, sep=',', header=T)
-        if (length(temp_dt[,eval(autoIncr)]) == 0) {
-          start = 1
-        } else {
-          start = tail(temp_dt[,eval(autoIncr)], 1) + 1
-        }
-        
-        end <- nrow(dat)+start-1
-        dat[, eval(autoIncr)] <- seq.int(start,end)
-      }
-    }
-    
-    
-    
-    write.table(dat, file=fpath, append=T, row.names=F, sep=',', col.names=F)
-    
-    return(TRUE)
-  }
-  
   if (is.null(db_pars)) {
     
     stop(getOption("TCPL_DRVR"), " is not a supported database system. See ",
