@@ -8,7 +8,6 @@
 
 tcplConf <- function (drvr = NULL, user = NULL, pass = NULL, host = NULL, 
                       db = NULL,...) {
-  #tcplConf(user='_dataminer', pass='pass', host='au.epa.gov', drvr = 'MySQL',db = 'invitrodb')
   
   # Notes for example
   # ==================
@@ -67,7 +66,7 @@ tcplConf <- function (drvr = NULL, user = NULL, pass = NULL, host = NULL,
       if (is.null(pass)) stop("'API' driver requires an API-key, supply it to ", 
                               "the 'pass' parameter. To request a key, send an ",
                               "email to ccte_api@epa.gov.")
-      if (is.null(host)) options("TCPL_HOST" = "https://api-ccte.epa.gov/bioactivity")
+      if (is.null(host)) options("TCPL_HOST" = "https://comptox.epa.gov/ctx-api/bioactivity")
       register_ctx_api_key(key = pass)
     }
     
