@@ -7,6 +7,14 @@
 #' @export
 
 tcplLoadAeid <- function(fld = NULL, val = NULL, add.fld = NULL) {
+  
+  if (getOption("TCPL_DRVR") == "API") {
+    dat <- tcplQueryAPI(resource = "assay", fld = fld, val = val, return_flds = c("aeid", "assay_component_endpoint_name", add.fld))
+    setnames(dat, "assay_component_endpoint_name", "aenm")
+    setorder(dat, "aeid")
+    return(unique(dat, by = c(fld, "aeid", "aenm")))
+  }
+  
   tbl = c("assay_component_endpoint", "assay", "assay_component")
   out <- c("assay_component_endpoint.aeid", 
            "assay_component_endpoint.assay_component_endpoint_name")
