@@ -7,6 +7,14 @@
 #' @export
 
 tcplLoadAid <- function(fld = NULL, val = NULL, add.fld = NULL) {
+  
+  if (getOption("TCPL_DRVR") == "API") {
+    dat <- tcplQueryAPI(resource = "assay", fld = fld, val = val, return_flds = c("aid", "assay_name", add.fld))
+    setnames(dat, "assay_name", "anm")
+    setorder(dat, "aid")
+    return(unique(dat, by = c(fld, "aid", "anm")))
+  }
+  
   tbl=c("assay")
   out <- c("assay.aid", 
            "assay.assay_name")
