@@ -58,7 +58,7 @@
 tcplSubsetChid <- function(dat, flag = TRUE, type = "mc", export_ready = FALSE) {
   ## Variable-binding to pass R CMD Check
   chit <- hitc <- aeid <- casn <- fitc <- fitc.ordr <- m4id <- nflg <- NULL
-  chid <- conc <- minc <- NULL
+  chid <- conc <- minc <- actc <- NULL
 
   if (!type %in% c("mc", "sc")) {
     stop("type must be sc (single concentration) or mc (multi-concentration)")
@@ -92,9 +92,9 @@ tcplSubsetChid <- function(dat, flag = TRUE, type = "mc", export_ready = FALSE)
     }
     if (!"casn" %in% names(dat)) dat <- tcplPrepOtpt(dat)
     # for now we treat all >=.9 hitcall equally
-    dat[, hitc := hitc >= .9]
-    dat[, chit := mean(hitc[hitc %in% 0:1]) >= 0.5, by = list(aeid, chid)]
-    dat <- dat[hitc == chit | (is.na(chit) & (hitc == -1 | is.na(m4id)))]
+    dat[, actc := hitc >= .9]
+    dat[, chit := mean(actc[actc %in% 0:1]) >= 0.5, by = list(aeid, chid)]
+    dat <- dat[actc == chit | (is.na(chit) & (actc == -1 | is.na(m4id)))]
 
 
     dat[, fitc.ordr := NA_integer_]
